@@ -1,14 +1,16 @@
+import os
+
 class Auth():
     SECRET_LIST = ["projectId", "userId", "accessToken", "refreshToken", "authorizationType"]
 
     def __new__(cls):
         if not hasattr(cls, 'instance'):
-            cls.instance = super(Singleton, cls).__new__(cls)
+            cls.instance = super(Auth, cls).__new__(cls)
         return cls.instance
 
     def __init__(self, *args, **kwargs):
         self.secret_mount_path = os.environ["secretMountPath"]
-        self.load_env(secret_mount_path)
+        self.load_env(self.secret_mount_path)
 
     def load_env(self, secret_mount_path):
         file_list = [f for f in os.listdir(self.secret_mount_path)]
