@@ -5,6 +5,5 @@ from mlplatform_lib.dataclass.experiment.type import ExperimentType
 @dataclass
 class InferenceDto:
     id: int = field(init=False, default=0)
-    experiment_id: int = field(init=False)
     experiment_type: ExperimentType = field(init=False)
-    inference_path: str
\ No newline at end of file
+    model_path: str
