@@ -1,7 +1,7 @@
 from mlplatform_lib.api_client import ApiClient, RunMode
 from mlplatform_lib.dataclass.model import ModelInfoDto
 from mlplatform_lib.hyperdata.hyperdata_api import HyperdataApi
-from mlplatform_lib.mlplatform.mlplatform_http_client import MlPlatformHttpClient, MlPlatformUserAuth
+from mlplatform_lib.mlplatform.mlplatform_http_client import MlPlatformHttpClient
 from mlplatform_lib.mlplatform.mlplatform_local_checker import MlPlatformLocalChecker
 import os
 from typing import List
@@ -29,12 +29,6 @@ class MlPlatformApi:
             self.mlplatform_addr = os.environ["mlplatformAddr"]
 
             self.mlplatform_client = MlPlatformHttpClient(mlplatform_addr=self.mlplatform_addr)
-            self.mlplatform_auth = MlPlatformUserAuth(
-                project_id=self.api_client.projectId,
-                user_id=self.api_client.userId,
-                authorization=self.api_client.Authorization,
-                authorization_type=self.api_client.authorizationType,
-            )
             self.train_do_id = int(os.environ["doId"]) if "doId" in os.environ else None
             self.inference_do_id = int(os.environ["doId"]) if "doId" in os.environ else None
             self.mount_path = self.api_client.pvc_mount_path
@@ -70,12 +64,14 @@ class MlPlatformApi:
 
     def get_experiment_path(self) -> str:
         experiment_path = os.path.join(self.mount_path, f"experiment-{self.experiment_id}")
-        Path(experiment_path).mkdir(parents=True, exist_ok=True)
+        if "servingMountPath" not in os.environ:
+            Path(experiment_path).mkdir(parents=True, exist_ok=True)
         return experiment_path
 
     def get_train_path(self) -> str:
         train_path = os.path.join(self.get_experiment_path(), f"train-{self.train_id}")
-        Path(train_path).mkdir(parents=True, exist_ok=True)
+        if "servingMountPath" not in os.environ:
+            Path(train_path).mkdir(parents=True, exist_ok=True)
         return train_path
 
     def get_prev_train_path(self) -> List[str]:
@@ -86,7 +82,8 @@ class MlPlatformApi:
 
     def get_inference_path(self):
         inference_path = os.path.join(self.get_experiment_path(), f"inference-{self.inference_id}")
-        Path(inference_path).mkdir(parents=True, exist_ok=True)
+        if "servingMountPath" not in os.environ:
+            Path(inference_path).mkdir(parents=True, exist_ok=True)
         return inference_path
 
     def get_inference_csv_path(self):
@@ -97,6 +94,5 @@ class MlPlatformApi:
             experiment_id=self.experiment_id,
             train_id=self.train_id,
             model_id=model_id,
-            model_info=model_info,
-            auth=self.mlplatform_auth,
+            model_info=model_info
         )
