@@ -6,6 +6,7 @@ from pathlib import Path
 from mlplatform_lib.dataclass.model import ModelInfoDto
 from datetime import datetime
 from mlplatform_lib.utils.dataclass_utils import to_dict, from_dict
+from mlplatform_lib.auth import Auth
 
 
 MLPLATFORM_TIMSTAMP_FORMAT = "%Y.%m.%d %H:%M:%S"
@@ -51,7 +52,7 @@ class MlPlatformHttpClient:
         service: str,
         rest: Optional[dict],
         query: Optional[dict],
-        data: Union[Optional[dict], Path]
+        data: Union[Optional[dict], Path],
         request_type: MlPlatformRequestType,
     ) -> MlPlatformRequestResult:
         auth = Auth()
@@ -59,9 +60,9 @@ class MlPlatformHttpClient:
         headers = {
             "Content-Type": "application/json",
             "Authorization": auth.authorization,
-            "userId": auth.user_id,
-            "projectId": auth.project_id,
-            "authorizationType": auth.authorization_type,
+            "userId": auth.userId,
+            "projectId": auth.projectId,
+            "authorizationType": auth.authorizationType,
         }
 
         if rest is None:
