@@ -1,6 +1,7 @@
 from typing import Dict
 import inspect
 import inflection
+from dataclasses import is_dataclass
 
 
 # dataclass field(init=False)로 지정되어 있는 변수들은
@@ -14,6 +15,7 @@ def from_dict(dataclass, dict: Dict):
     for key, val in dict.items():
         # camel case to snake case
         key = inflection.underscore(key)
+
         if key in sig.parameters.keys():
             init_dict[key] = val
         else:
@@ -26,4 +28,17 @@ def from_dict(dataclass, dict: Dict):
 
 
 def to_dict(instance):
-    return {inflection.camelize(key, False): val for key, val in instance.__dict__.items()}
+    result = {}
+    for k, v in instance.__dict__.items():
+        if is_dataclass(v):
+            result[inflection.camelize(k, False)] = to_dict(v)
+        elif isinstance(v, list):
+            result[inflection.camelize(k, False)] = []
+            for v_elem in v:
+                if is_dataclass(v_elem):
+                    result[inflection.camelize(k, False)].append(to_dict(v_elem))
+                else:
+                    result[inflection.camelize(k, False)].append(v_elem)
+        else:
+            result[inflection.camelize(k, False)] = v
+    return result
